IntListCodec class

Inheritance

Constructors

IntListCodec()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tSizeInBytes → int
finalinherited

Methods

decode(ByteBuffer buffer) → List<int>
inherited
encode(List<int> data) → ByteBuffer
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited