OnceCell<T extends Object> class abstract interface

OnceCell, A cell which can be written to only once.

Equality: Cells are equal if they have the same value or are not set.

Hash: Cells hash to their existing or the same if not set.

Implemented types

Constructors

OnceCell()
factory
OnceCell.withValue(T val)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get() → Option<T>
Gets the reference to the underlying value.
getOrInit(T func()) → T
Gets the contents of the cell, initializing it with func if the cell was empty.
inherited
getOrNull() → T?
Gets the underlying value, returns null if the cell is empty
inherited
getOrTryInit<E extends Object>(Result<T, E> f()) → Result<T, E>
Gets the contents of the cell, initializing it with f if the cell was empty. If the cell was empty and f failed, an error is returned.
inherited
isSet() → bool
Returns true if the value has been set. Returns false otherwise.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(T value) → Result<(), T>
Sets the contents of the cell to value.
setOrNull(T value) → T?
Sets the contents of the cell to value. Returns null if the value is already set.
inherited
take() → Option<T>
Takes the value out of this OnceCell, moving it back to an uninitialized state.
takeOrNull() → T?
Takes the value out of this OnceCell, moving it back to an uninitialized state. Returns null if the cell is empty.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited