SliceIterator<T> class final

An iterator over the elements of a Slice.

Implemented types
Available extensions

Constructors

SliceIterator(Slice<T> _slice, int _index)

Properties

current → T
The current element.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJSIterator → JSIterator<T>

Available on Iterator<T>, provided by the IteratorToJSIterator extension

A JSIterator wrapper that proxies to the Dart iterator API.
no setter

Methods

collectVec() → Vec<T>

Available on Iterator<T>, provided by the VecOnIteratorExtension extension

iter() → Iter<T>

Available on Iterator<T>, provided by the IteratorExtension extension

Returns an Iter for this Iterator.
moveNext() → bool
Advances the iterator to the next element of the iteration.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited